@@ -18,4 +18,6 @@ git rm --ignore-unmatch -r -f \
     assets/thirdparties/www.fanboy.co.nz/fanboy-antifacebook.txt \
     assets/thirdparties/www.zoso.ro \
     assets/thirdparties/home.fredfiber.no \
+    uAssets/thirdparties/mirror1.malwaredomains.com \
+    uAssets/thirdparties/pgl.yoyo.org \
     platform/safari/vapi-background.js
